// ----------------------------------------------------------------------------
// Zoom Search Engine 4.2 (24/11/2005)
//
// This file (search.js) is the JavaScript search front-end for client side
// searches using index files created by the Zoom Search Engine Indexer.
//
// email: zoom@wrensoft.com
// www: http://www.wrensoft.com
//
// Copyright (C) Wrensoft 2000-2005
//
// This script performs client-side searching with the index data file
// (zoom_index.js) generated by the Zoom Search Engine Indexer. It allows you
// to run searches on mediums such as CD-ROMs, or other local data, where a
// web server is not available.
//
// We recommend against using client-side searches for online websites because
// it requires the entire index data file to be downloaded onto the user's
// local machine. This can be very slow for large websites, and our server-side
// search scripts (available for PHP, ASP and CGI) are far better suited for this.
// However, JavaScript is still an option for smaller websites in a limited
// hosting situation (eg: your web host does not support PHP, ASP or CGI).
// ----------------------------------------------------------------------------

// Include required files for index data, settings, etc.
document.write("<script language=\"JavaScript\" src=\"zoom_index.js\" charset=\"" + Charset + "\"><\/script>");
document.write("<script language=\"JavaScript\" src=\"zoom_pages.js\" charset=\"" + Charset + "\"><\/script>");
document.write("<script language=\"JavaScript\" src=\"zoom_titles.js\" charset=\"" + Charset + "\"><\/script>");
document.write("<script language=\"JavaScript\" src=\"zoom_descriptions.js\" charset=\"" + Charset + "\"><\/script>");

document.write("<meta http-equiv=\"content-type\" content=\"text/html; charset=" + Charset + "\">");

// ----------------------------------------------------------------------------
// Settings (change if necessary)
// ----------------------------------------------------------------------------

// The options available in the dropdown menu for number of results
// per page
var PerPageOptions = new Array(10, 20, 50, 100);

// Globals
var SkippedWords = 0;
var searchWords = new Array();
var SkippedOutputStr = "";
var hlwords = "";
var fixup = 0;

var months = new Array('Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec');

// ----------------------------------------------------------------------------
// Helper Functions
// ----------------------------------------------------------------------------

// This function will return the value of a GET parameter
function getParam(paramName)
{
    paramStr = document.location.search;
    if (paramStr == "")
        return "";

    // remove '?' in front of paramStr
    if (paramStr.charAt(0) == "?")
        paramStr = paramStr.substr(1);

    arg = (paramStr.split("&"));
    for (i=0; i < arg.length; i++) {
        arg_values = arg[i].split("=")
        if (unescape(arg_values[0]) == paramName) {
            if (UseUTF8 == 1 && self.decodeURIComponent) // check if decodeURIComponent() is defined
                ret = decodeURIComponent(arg_values[1]);
            else
                ret = unescape(arg_values[1]);  // IE 5.0 and older does not have decodeURI
            return ret;
        }
    }
    return "";
}

// Compares the two values, used for sorting output results
// Results that match all search terms are put first, highest score
function SortCompare (a, b)
{
    if (a[2] < b[2]) return 1;
    else if (a[2] > b[2]) return -1;
    else if (a[1] < b[1]) return 1;
    else if (a[1] > b[1]) return -1;
    else return 0;
}

function SortByDate(a, b)
{
	if (datetime[a[0]] < datetime[b[0]]) return 1;
	else if (datetime[a[0]] > datetime[b[0]]) return -1;
	else return SortCompare(a, b);
}

function sw_compare(a, b)
{
	if (a.charAt(0) == '-') 
		return 1;
	
	if (b.charAt(0) == '-') 
		return -1;
	
	return 0;
}

function pattern2regexp(pattern)
{
    pattern = pattern.replace(/\#/g, "\\#");
    pattern = pattern.replace(/\$/g, "\\$");
    pattern = pattern.replace(/\./g, "\\.");
    pattern = pattern.replace(/\*/g, "[\\d\\S]*");
    pattern = pattern.replace(/\?/g, ".?");
    return pattern;
}

function HighlightDescription(line) {
    res = " " + line + " ";
    for (i = 0; i < numwords; i++) {
        if (searchWords[i] == "")
            continue;

        if (SearchAsSubstring == 1)
            res = res.replace(new RegExp("("+searchWords[i]+")", "gi"), "[;:]$1[:;]");
        else
            res = res.replace(new RegExp("(\\W|^|\\b)("+searchWords[i]+")(\\W|$|\\b)", "gi"), "$1[;:]$2[:;]$3");
    }
    // replace the marker text with the html text
    // this is to avoid finding previous <span>'ed text.
    res = res.replace(/\[;:\]/g, "<span class=\"highlight\">");
    res = res.replace(/\[:;\]/g, "</span>");
    return res;
}

function PrintNumResults(num)
{
    if (num == 0)
        return STR_NO_RESULTS;
    else if (num == 1)
        return num + " " + STR_RESULT;
    else
        return num + " " + STR_RESULTS;
}

function AddParamToURL(url, paramStr)
{
	// add GET parameters to URL depending on 
	// whether there are any existing parameters
	if (url.indexOf("?") > -1)	
		return url + "&amp;" + paramStr;
	else		
		return url + "?" + paramStr;			
}

function SkipSearchWord(sw) {
    if (searchWords[sw] != "") {
        if (SkippedWords > 0)
            SkippedOutputStr += ", ";
        SkippedOutputStr += "\"<b>" + searchWords[sw] + "</b>\"";
        searchWords[sw] = "";
    }
}

// ----------------------------------------------------------------------------
// Parameters initialisation (globals)
// ----------------------------------------------------------------------------

var query = getParam("zoom_query");
query = query.replace(/[\++]/g, " ");  // replace the '+' with spaces
query = query.replace(/[,+]/g, " ");
query = query.replace(/\</g, "&lt;");
query = query.replace(/[\"+]/g, " ");

var per_page = parseInt(getParam("zoom_per_page"));
if (isNaN(per_page)) per_page = 10;

var page = parseInt(getParam("zoom_page"));
if (isNaN(page)) page = 1;

var andq = parseInt(getParam("zoom_and"));
if (isNaN(andq))
{
	if (typeof(DefaultToAnd) != "undefined" && DefaultToAnd == 1)
		andq = 1;
	else
		andq = 0;
}

var cat = parseInt(getParam("zoom_cat"));
if (isNaN(cat)) cat = -1;   // search all categories

// for sorting options. zero is default (relevance)
// 1 is sort by date (if date/time is available)
var sort = parseInt(getParam("zoom_sort"));
if (isNaN(sort)) sort = 0;

var SelfURL = "";
if (typeof(LinkBackURL) == "undefined")
{
    SelfURL = document.location.href;
    var paramIndex = SelfURL.indexOf("?");
    if (paramIndex > -1)
        SelfURL = SelfURL.substr(0, paramIndex);    // strip off the parameters
}
else
    SelfURL = LinkBackURL;
SelfURL = SelfURL.replace(/\</g, "&lt;");

var data = new Array();
var output = new Array();

target = "";
if (UseLinkTarget == 1)
    target = " target=\"" + LinkTarget + "\" ";

// ----------------------------------------------------------------------------
// Main search function starts here
// ----------------------------------------------------------------------------

function ZoomSearch() {
	var buttonPrevious = '<img src="../../common/bb.gif" alt="Rubrique précédente" border="0">';
	var buttonNext = '<img src="../../common/ff.gif" alt="Rubrique suivante" border="0">';

    if (Timing == 1) {
        timeStart = new Date();
    }

    // Display the form
    if (FormFormat > 0) {
        document.writeln("<form name=\"search\" method=\"get\" action=\"" + SelfURL + "\" class=\"zoom_searchform\">");
        document.writeln("<table border='0' width='100%' cellpadding='4' cellspacing='0'><tr><td>&#160;</td></tr>");
        document.write("<tr><td width=\"15%\"><input type=\"text\" name=\"zoom_query\" size=\"20\" value=\"" + query + "\" class=\"zoom_searchbox\" /></td>");
				document.write('<td><TABLE BORDER="0" cellpadding="0" cellspacing="0"><TR><TD colspan="3" bgColor="#666699"><IMG src="../../common/spacer.gif" height="1" width="1" border="0" alt=""></TD></TR><TR><TD bgColor="#666699" width="1"><IMG src="../../common/spacer.gif" height="16" width="1" border="0" alt=""></TD><TD valign="middle" align="left" bgColor="#DDDDFF"><FONT face="Tahoma, Arial, Geneva, Helvetica, sans-serif" color="#666699" size="2"><input type="image" src="../../common/search.gif" value="search" name="search" alt="Recherche"></FONT></TD><TD bgColor="#666699" width="1"><IMG src="../../common/spacer.gif" height="16" width="1" border="0" alt=""></TD></TR><TR><TD colspan="3" bgColor="#666699"><IMG src="../../common/spacer.gif" height="1" width="1" border="0" alt=""></TD></TR>');
        document.write('</TABLE></td>');
        if (query.length == 0) 
        		document.write("<tr><td colspan='2' class=\"xresult\">Les caractères génériques (* et ?) sont pris en charge.<br/>Les phrases correspondant exactement ne le sont pas.</td></tr>");
				document.write("</tr></table>");
//        document.writeln("<input type=\"submit\" value=\"" + STR_FORM_SUBMIT_BUTTON + "\" class=\"zoom_button\" />");
        if (FormFormat == 2) {
/*            document.writeln("<span class=\"body\">" + STR_FORM_RESULTS_PER_PAGE + "\n");
//            document.writeln("<select name='zoom_per_page'>");
//            for (i = 0; i < PerPageOptions.length; i++) {
//                document.write("<option");
//                if (PerPageOptions[i] == per_page)
//                    document.write(" selected=\"selected\"");
//                document.writeln(">" + PerPageOptions[i] + "</option>");
//            }
            document.writeln("</select><br /><br />");
            if (UseCats) {
                document.write(STR_FORM_CATEGORY + " ");
                document.write("<select name='zoom_cat'>");
                // 'all cats option
                document.write("<option value=\"-1\">" + STR_FORM_CATEGORY_ALL + "</option>");
                for (i = 0; i < catnames.length; i++) {
                    document.write("<option value=\"" + i + "\"");
                    if (i == cat)
                        document.write(" selected=\"selected\"");
                    document.writeln(">" + catnames[i] + "</option>");
                }
                document.writeln("</select>&nbsp;&nbsp;");
            }
            */
//            document.writeln(STR_FORM_MATCH + " ");
/*            if (andq == 0) {
                document.writeln("<span class=\"body\"><input type=\"radio\" name=\"zoom_and\" value=\"0\" checked=\"checked\" />" + STR_FORM_ANY_SEARCH_WORDS);
                document.writeln("<input type=\"radio\" name=\"zoom_and\" value=\"1\" />" + STR_FORM_ALL_SEARCH_WORDS);                                
            } else {
                document.writeln("<span class=\"body\"><input type=\"radio\" name=\"zoom_and\" value=\"0\" />" + STR_FORM_ANY_SEARCH_WORDS);
                document.writeln("<input type=\"radio\" name=\"zoom_and\" value=\"1\" checked=\"checked\" />" + STR_FORM_ALL_SEARCH_WORDS);                
            }
*/
            document.writeln("<input type=\"hidden\" name=\"zoom_sort\" value=\"" + sort + "\" />");
            document.writeln("</span>");
        }
        else
        {
        	document.writeln("<input type=\"hidden\" name=\"zoom_per_page\" value=\"" + per_page + "\" />");
        	document.writeln("<input type=\"hidden\" name=\"zoom_and\" value=\"" + andq + "\" />");
        	document.writeln("<input type=\"hidden\" name=\"zoom_sort\" value=\"" + sort + "\" />");
        }
        
        document.writeln("</form>");
    }

    // give up early if no search words provided
    if (query.length == 0) {
        //document.writeln("No search query entered.<br />");        
        if (ZoomInfo == 1)
            document.writeln("<center><p><small>" + STR_POWEREDBY + " <a href=\"http://www.wrensoft.com/zoom/\" target=\"_blank\"><b>Zoom Search Engine</b></a></small></p></center>");
        return;
    }

    if (MapAccents == 1) {
        for (i = 0; i < NormalChars.length; i++) {
            query = query.replace(AccentChars[i], NormalChars[i]);
        }
    }

    if (ToLowerSearchWords == 1)
        query = query.toLowerCase();

    // prepare search query, strip quotes, trim whitespace
    if (WordJoinChars.indexOf(".") == -1)
        query = query.replace(/[\.+]/g, " ");

    if (WordJoinChars.indexOf("-") == -1)
        query = query.replace(/(\S)\-/g, "$1 ");

    if (WordJoinChars.indexOf("_") == -1)
        query = query.replace(/[\_+]/g, " ");

    if (WordJoinChars.indexOf("'") == -1)
        query = query.replace(/[\'+]/g, " ");

    if (WordJoinChars.indexOf("#") == -1)
        query = query.replace(/[\#+]/g, " ");

    if (WordJoinChars.indexOf("$") == -1)
        query = query.replace(/[\$+]/g, " ");

    if (WordJoinChars.indexOf("&") == -1)
        query = query.replace(/[\&+]/g, " ");

    if (WordJoinChars.indexOf(":") == -1)
        query = query.replace(/[\:+]/g, " ");

    //    if (WordJoinChars.indexOf(",") == -1)
    //      query = query.replace(/[\,+]/g, " ");

    // substitute multiple whitespace chars to single character
    query = query.replace(/[\/\s\\\\(\)\^\[\]\|\+\{\}]+/g, " ");    

    // trim trailing/leading whitespace
    query = query.replace(/^\s*|\s*$/g,""); 

    // split search phrase into words
    searchWords = query.split(" "); // split by spaces.
    
    // Sort search words if there are negative signs
    if (query.indexOf("-") != -1)
    	searchWords.sort(sw_compare);      

    document.write("<h3>" + STR_RESULTS_FOR);
    if (UseCats) {
        if (cat == -1)
            document.writeln(" " + STR_RESULTS_IN_ALL_CATEGORIES);
        else
            document.writeln(" " + STR_RESULTS_IN_CATEGORY + " \"" + catnames[cat] + "\"");
    }
    document.writeln("</h3>");

    document.writeln("<div class=\"xresult\">");

    numwords = searchWords.length;
    kw_ptr = 0;
    outputline = 0;
    usewildcards = 0;
    ipage = 0;
    matches = 0;
    var SWord;
    pagesCount = urls.length;
    exclude_count = 0;
    ExcludeTerm = 0;
    
    // Initialise a result table the size of all pages
    res_table = new Array(pagesCount);
    for (i = 0; i < pagesCount; i++)
    {
        res_table[i] = new Array(3);
        res_table[i][0] = 0;
        res_table[i][1] = 0;
        res_table[i][2] = 0;
    }

skipped = 0;
    if (skipwords) {
        for (sw = 0; sw < numwords; sw++) {
	        	skipped = 0;
            // check min length
            if (searchWords[sw].length < MinWordLen) {
                SkipSearchWord(sw);
                skipped = 1;
                continue;
            }
            // check skip word list
            for (i = 0; i < skipwords.length; i++) {
                if (searchWords[sw] == skipwords[i]) {
                    SkipSearchWord(sw);
                    skipped = 1;
                    break;
                }
            }
            if (!skipped) {
	          	if (hlwords == "")
			    				hlwords += searchWords[sw];
			    			else
			    				hlwords += "+" + searchWords[sw];
			    	}
        }
    }
  	else {
  		hlwords = query;
  		fixup = 1;
  	}
  	
    
    if (SkippedWords > 0) 
        document.writeln("<i>" + STR_SKIPPED_FOLLOWING_WORDS + " " + SkippedOutputStr + ".</i><br /><br />");


    // Begin searching...
    for (sw = 0; sw < numwords; sw++) {

        if (searchWords[sw] == "") {
        	SkippedWords++;
            continue;
        }

		if (searchWords[sw].charAt(0) == '-')
		{			
			searchWords[sw] = searchWords[sw].substr(1);			
			ExcludeTerm = 1;
			exclude_count++;			
		}
		
        if (searchWords[sw].indexOf("*") == -1 && searchWords[sw].indexOf("?") == -1) {
            UseWildCards = 0;
        } else {
            UseWildCards = 1;
            searchWords[sw] = pattern2regexp(searchWords[sw]);
            if (SearchAsSubstring == 0)
                pattern = "^" + searchWords[sw] + "$";
            else
                pattern = searchWords[sw];

            re = new RegExp(pattern, "g");
        }

        for (kw_ptr = 0; kw_ptr < dictwords.length; kw_ptr++) {

            data = dictwords[kw_ptr].split(",");

            if (UseWildCards == 0) {
                if (SearchAsSubstring == 0)
                    //match_result = data[0].search("^" + SWord + "$");
                    if (data[0] == searchWords[sw])
                        match_result = 0;
                    else
                        match_result = -1;
                else
                    match_result = data[0].indexOf(searchWords[sw]);
            } else
                match_result = data[0].search(re);


            if (match_result != -1) {
                // keyword found, include it in the output list

                for (kw = 1; kw < data.length; kw += 2) {
                    // check if page is already in output list
                    pageexists = 0;
                    ipage = data[kw];
                    
                    if (ExcludeTerm == 1)
                    {
                    	// we clear out the score entry so that it'll be excluded in the filter stage
                    	res_table[ipage][0] = 0;
                    }                    
                    else if (res_table[ipage][0] == 0) {
                        matches++;
                        res_table[ipage][0] += parseInt(data[kw+1]);
                    }
                    else {

                        if (res_table[ipage][0] > 10000) {
                            // take it easy if its too big to prevent gigantic scores
                            res_table[ipage][0] += 1;
                        } else {
                            res_table[ipage][0] += parseInt(data[kw+1]); // add in score
                            res_table[ipage][0] *= 2;           // double score as we have two words matching
                        }
                    }
                    res_table[ipage][1] += 1;
                    // store the 'and' user search terms matched' value
                    if (res_table[ipage][2] == sw || res_table[ipage][2] == sw-SkippedWords-exclude_count)
                        res_table[ipage][2] += 1;

                }
                if (UseWildCards == 0 && SearchAsSubstring == 0)
                    break;    // this search word was found, so skip to next
            }
        }
	}
    
    if (SkippedWords > 0)
        document.writeln("<i>" + STR_SKIPPED_FOLLOWING_WORDS + " " + SkippedOutputStr + ".</i><br /><br />");

    // Count number of output lines that match ALL search terms
    oline = 0;
    fullmatches = 0;    
    output = new Array();
    var full_numwords = numwords - SkippedWords - exclude_count;
    for (i = 0; i < pagesCount; i++) {
        IsFiltered = false;
        if (res_table[i][0] > 0) {
            if (UseCats && cat != -1) {
                // using cats and not doing an "all cats" search
                if (catpages[i] != cat) {
                    IsFiltered = true;
                }
            }
            if (IsFiltered == false) {
                if (res_table[i][2] >= full_numwords) {
                    fullmatches++;
                } else {
                    if (andq == 1)
                        IsFiltered = true;
                }
            }
            if (IsFiltered == false) {
                // copy if not filtered out
                output[oline] = new Array(3);
                output[oline][0] = i;
                output[oline][1] = res_table[i][0];
                output[oline][2] = res_table[i][1];
                oline++;
            }
        }
    }
    matches = oline;    

    // Sort results in order of score, use "SortCompare" function
    if (matches > 1)    
   	{
   		if (sort == 1 && UseDateTime == 1)
   			output.sort(SortByDate);	// sort by date
   		else
        	output.sort(SortCompare);	// sort by relevance
    }
    
    // prepare query_out
    var query_out = query.replace(/\s/g, "+");
	if (UseUTF8 == 1 && self.encodeURIComponent){
		query_out = encodeURIComponent(query_out);
		if (fixup) {
    	hlwords = hlwords.replace(/\s/g, "+");
    	hlwords = encodeURIComponent(hlwords);
    }
  }
	else {
		query_out = escape(query_out);  
		if (fixup) {
			hlwords = hlwords.replace(/\s/g, "+");
			hlwords = escape(hlwords);
		}  
	}

    //Display search result information
    document.writeln("<div class=\"body\">");
    if (matches == 0)
        document.writeln(STR_SUMMARY_NO_RESULTS_FOUND + "<br />");
/*    else if (numwords > 1 && andq == 0) {
        //OR
        SomeTermMatches = matches - fullmatches;
        document.writeln(PrintNumResults(fullmatches) + " " + STR_SUMMARY_FOUND_CONTAINING_ALL_TERMS + " ");
        if (SomeTermMatches > 0)
            document.writeln(PrintNumResults(SomeTermMatches) + " " + STR_SUMMARY_FOUND_CONTAINING_SOME_TERMS);
        document.writeln("<br />");
    }
    else if (numwords > 1 && andq == 1) //AND
        document.writeln(PrintNumResults(fullmatches) + " " + STR_SUMMARY_FOUND_CONTAINING_ALL_TERMS + "<br />");
//    else
//        document.writeln("<b>" + PrintNumResults(matches) + " " + STR_SUMMARY_FOUND + "</b><br />");
*/
    document.writeln("</div>\n");

    // number of pages of results
    num_pages = Math.ceil(matches / per_page);
//    if (num_pages > 1)
//        document.writeln("<p class=\"body\">" + num_pages + " " + STR_PAGES_OF_RESULTS + "</p>\n");
        
    // Show sorting options
    if (matches > 1)
    {
    	if (UseDateTime == 1)
    	{
    		document.writeln("<div class=\"sorting\">");
    		if (sort == 1)
				document.writeln("<a href=\"" + SelfURL + "?zoom_query=" + hlwords + "&amp;zoom_page=" + page + "&amp;zoom_per_page=" + per_page + "&amp;zoom_cat=" + cat + "&amp;zoom_and=" + andq + "&amp;zoom_sort=0\">" + STR_SORTBY_RELEVANCE + "</a> / <b>" + STR_SORTEDBY_DATE + "</b>");
			else
				document.writeln("<b>" + STR_SORTEDBY_RELEVANCE + "</b> / <a href=\"" + SelfURL + "?zoom_query=" + hlwords + "&amp;zoom_page=" + page + "&amp;zoom_per_page=" + per_page + "&amp;zoom_cat=" + cat + "&amp;zoom_and=" + andq + "&amp;zoom_sort=1\">" + STR_SORTBY_DATE + "</a>");
			document.writeln("</div>");
    	}    	
    }    

    // determine current line of result from the output array
    if (page == 1) {
        arrayline = 0;
    } else {
        arrayline = ((page - 1) * per_page);
    }

    // the last result to show on this page
    result_limit = arrayline + per_page;

    // display the results
    while (arrayline < matches && arrayline < result_limit) {
        ipage = output[arrayline][0];
        score = output[arrayline][1];
        
        document.writeln("<p></p>\n");
        
        document.writeln("<div class=\"xtitle\">");
        if (DisplayNumber == 1)
//        	document.writeln("<b>" + (arrayline+1) + ".</b>&nbsp;");
					document.writeln((arrayline+1) + ".&nbsp;");
        	
        urlLink = urls[ipage];
    	if (GotoHighlight == 1)				
    	{
    		if (SearchAsSubstring == 1)
    			urlLink = AddParamToURL(urlLink, "zoom_highlightsub=" + hlwords);
    		else
    			urlLink = AddParamToURL(urlLink, "zoom_highlight=" + hlwords);
		}			
        if (DisplayTitle == 1)
        {
       		document.writeln("<a href=\"" + urlLink + "\"" + target + ">");
       		if (Highlighting == 1)
                document.writeln(HighlightDescription(titles[ipage]));
            else
       			document.writeln(titles[ipage]);
       		document.writeln("</a>");
        }        
        else
        	document.writeln("<a href=\"" + urlLink + "\"" + target + ">" + urls[ipage] + "</a>");
                   
        if (UseCats) 
        {
        	catindex = catpages[ipage];
            document.writeln("<span class=\"category\">[" + catnames[catindex] + "]</span>");
        }
        document.writeln("</div>");
        
        if (DisplayMetaDesc == 1)
        {
        	// print meta description
            document.writeln("<div class=\"xresult\">");
            if (Highlighting == 1)
                document.writeln(HighlightDescription(descriptions[ipage]));
            else
                document.writeln(descriptions[ipage]);
            document.writeln("</div>\n");
        }
        
        info_str = "";
        
        if (DisplayTerms == 1)
        	info_str += STR_RESULT_TERMS_MATCHED + " " + output[arrayline][2];
        	
        if (DisplayScore == 1) {
        	if (info_str.length > 0)
        		info_str += "&nbsp; - &nbsp;";
        	info_str += STR_RESULT_SCORE + " " + score;
        }
        
        if (DisplayDate == 1) {
        	if (info_str.length > 0)
        		info_str += "&nbsp; - &nbsp;";
        	info_str += datetime[ipage].getDate() + " " + months[datetime[ipage].getMonth()] + " " + datetime[ipage].getFullYear();
        }
             
        if (DisplayURL == 1) {
        	if (info_str.length > 0)
        		info_str += "&nbsp; - &nbsp;";
			info_str += STR_RESULT_URL + " " + urls[ipage];
        }
                   
        document.writeln("<div class=\"infoline\">");
        document.writeln(info_str);                        
        document.writeln("</div>\n");
        arrayline++;
    }

    // Show links to other result pages
    if (num_pages > 1) {
        // 10 results to the left of the current page
        start_range = page - 10;
        if (start_range < 1)
            start_range = 1;

        // 10 to the right
        end_range = page + 10;
        if (end_range > num_pages)
            end_range = num_pages;

        document.writeln("<p></p>" + STR_RESULT_PAGES + " ");
        if (page > 1)
            document.writeln("<a href=\"" + SelfURL + "?zoom_query=" + hlwords + "&amp;zoom_page=" + (page-1) + "&amp;zoom_per_page=" + per_page + "&amp;zoom_cat=" + cat + "&amp;zoom_and=" + andq + "&amp;zoom_sort=" + sort + "\"> " + buttonPrevious + "</a> ");

        for (i = start_range; i <= end_range; i++) {
            if (i == page) {
                document.writeln(page + " ");
            } else {
                document.writeln("<a href=\"" + SelfURL + "?zoom_query=" + hlwords + "&amp;zoom_page=" + i + "&amp;zoom_per_page=" + per_page + "&amp;zoom_cat=" + cat + "&amp;zoom_and=" + andq + "&amp;zoom_sort=" + sort + "\">" + i + "</a> ");
            }
        }

        if (page != num_pages)
            document.writeln("<a href=\"" + SelfURL + "?zoom_query=" + hlwords + "&amp;zoom_page=" + (page+1) + "&amp;zoom_per_page=" + per_page + "&amp;zoom_cat=" + cat + "&amp;zoom_and=" + andq + "&amp;zoom_sort=" + sort + "\">" + buttonNext + " </a> ");
        document.writeln("<p> </p>");
    }

    document.writeln("</div>"); // end results style tag

    if (Timing == 1) {
        timeEnd = new Date();
        timeDifference = timeEnd - timeStart;
        document.writeln("<br /><br /><small>" + STR_SEARCH_TOOK + " " + (timeDifference/1000) + " " + STR_SECONDS + ".</small>\n");
    }

    if (ZoomInfo == 1)
        document.writeln("<center><p><small>" + STR_POWEREDBY + " <a href=\"http://www.wrensoft.com/zoom/\" target=\"_blank\"><b>Zoom Search Engine</b></a></small></p></center>");
}

